@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 import asyncio
 from collections import defaultdict
 from contextlib import suppress
 from datetime import datetime, timedelta
 from glob import glob
 from pathlib import Path
-from typing import List
+from typing import TYPE_CHECKING
 
 import numpy as np
 import pandas as pd
@@ -20,8 +22,11 @@ from ipywidgets import (
     VBox,
 )
 
+if TYPE_CHECKING:
+    from adaptive_scheduler.server_support import RunManager
 
-def _get_fnames(run_manager, only_running: bool) -> List[Path]:
+
+def _get_fnames(run_manager, only_running: bool) -> list[Path]:
     if only_running:
         fnames = []
         for entry in run_manager.database_manager.as_dicts():
@@ -51,7 +56,7 @@ def _failed_job_logs(fnames, run_manager, only_running):
     failed = fnames - running
     failed = [Path(f) for stem in failed for f in glob(f"{stem}*")]
 
-    def maybe_append(fname: str, other_dir: Path, lst: List[Path]):
+    def maybe_append(fname: str, other_dir: Path, lst: list[Path]):
         p = Path(fname)
         p_other = other_dir / p.name
         if p.exists():
@@ -146,10 +151,16 @@ def _sort_fnames(sort_by, run_manager, fnames):
     return fnames
 
 
-def _read_file(fname: Path) -> str:
+def _read_file(fname: Path, max_lines: int = 500) -> str:
     try:
         with fname.open("r", encoding="utf-8") as f:
-            return "".join(f.readlines())
+            lines = f.readlines()
+
+            if len(lines) > max_lines:
+                lines = lines[-max_lines:]
+                lines.insert(0, f"Only displaying the last {max_lines} lines!")
+                lines.insert(1, "\n")
+            return "".join(lines)
     except UnicodeDecodeError:
         return f"Could not decode file ({fname})!"
     except Exception as e:
@@ -195,7 +206,7 @@ def log_explorer(run_manager) -> VBox:  # noqa: C901
             try:
                 T_new = _last_editted(fname)
                 if T_new > T:
-                    textarea.value = _read_file(fname)
+                    textarea.value = _read_file(fname, run_manager.max_log_lines)
                     T = T_new
             except asyncio.CancelledError:
                 return
@@ -245,7 +256,7 @@ def log_explorer(run_manager) -> VBox:  # noqa: C901
                 and change["name"] == "value"
                 and change["new"] is not None
             ):
-                textarea.value = _read_file(change["new"])
+                textarea.value = _read_file(change["new"], run_manager.max_log_lines)
 
         return on_change
 
@@ -258,7 +269,7 @@ def log_explorer(run_manager) -> VBox:  # noqa: C901
 
     fnames = _get_fnames(run_manager, only_running=False)
     # no need to sort `fnames` because the default sort_by option is alphabetical
-    text = _read_file(fnames[0]) if fnames else ""
+    text = _read_file(fnames[0], run_manager.max_log_lines) if fnames else ""
     textarea = Textarea(text, layout=dict(width="auto"), rows=20)
     sort_by_dropdown = Dropdown(
         description="Sort by",
@@ -392,7 +403,7 @@ def _info_html(run_manager) -> str:
     """
 
 
-def info(run_manager) -> None:
+def info(run_manager: RunManager) -> None:
     """Display information about the `RunManager`.
 
     Returns an interactive ipywidget that can be
